@@ -2,8 +2,8 @@ import re
 class Router(object):
     def __init__(self):
         self.routes = []
-
-    def create_route_expression(self, route):
+    @staticmethod
+    def create_route_expression(route):
         expression = re.sub(r'(<\w+>)', r'(?P\1.+)', route)
         return re.compile(f"^{expression}$")
 
@@ -22,4 +22,4 @@ class Router(object):
             m = routexp.match(url)
             if(m):
                 return m.groupdict(), func, server_options
-        return None
\ No newline at end of file
+        return None
